
/*  $Id: cert.c,v 1.3 2003/01/21 08:49:43 lteo Exp $ */

/*
 *  cert.c:  generates SPEED certification data.
 *
 *  Copyright (c) 2003 Calyptix Security Corporation
 *  All rights reserved.
 *
 *  This code is derived from software contributed to Calyptix Security
 *  Corporation by Yuliang Zheng.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions
 *  are met:
 *  1. Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above
 *     copyright notice, this list of conditions and the following
 *     disclaimer in the documentation and/or other materials provided
 *     with the distribution.
 *  3. Neither the name of Calyptix Security Corporation nor the
 *     names of its contributors may be used to endorse or promote
 *     products derived from this software without specific prior
 *     written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
 * COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
 * ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *
 * -------------------------------------------------------------------
 */

static char rcsid[] = "$Id: cert.c,v 1.3 2003/01/21 08:49:43 lteo Exp $";

#include <stdio.h>
#include <string.h>
#include "speedc.h"


#if   SPEED_DATA_LEN == 256
#define F_WD_MASK       0x0FFFFFFFFL
#define H_WD_MASK       0x0FFFF
#elif SPEED_DATA_LEN == 128
#define F_WD_MASK       0x0FFFF
#define H_WD_MASK       0x0FF
#else /* SPEED_DATA_LEN == 64 */
#define F_WD_MASK       0x0FF
#define H_WD_MASK       0x0F
#endif


int main (int  argc, char *argv[])
{

  int           i;
  speed_key     key; 
  speed_data    pt, pt2; 
  speed_data    ct;

  for (i=0; i<SPEED_DATA_LEN_BYTE; i++) {
    pt[i] = i;
  }

  for (i=0; i<SPEED_KEY_LEN_BYTE; i++) {
    key[i] = 'A' + i;
  }

  speed_encrypt(pt, ct, key);
  speed_decrypt(pt2, ct, key);

  printf ("SPEED_DATA_LEN = %d, SPEED_KEY_LEN = %d, SPEED_NO_OF_RND = %d\n",
           SPEED_DATA_LEN, SPEED_KEY_LEN, SPEED_NO_OF_RND);

  printf ("key        = ");
  for (i=0; i<SPEED_KEY_LEN_BYTE; i++) {
    printf ("%02X ", key[SPEED_KEY_LEN_BYTE-1-i]);
    if (i+1 ==16) printf ("\n             ");
  }
  printf ("\n");

  printf ("plaintext  = ");
  for (i=0; i< SPEED_DATA_LEN_BYTE; i++) {
    printf ("%02X ", pt[SPEED_DATA_LEN_BYTE - 1 -i]);
    if (i+1 ==16) printf ("\n             ");
  }
  printf ("\n");

  printf ("ciphertext = ");
  for (i=0; i< SPEED_DATA_LEN_BYTE; i++) {
    printf ("%02X ", ct[SPEED_DATA_LEN_BYTE - 1 -i]);
    if (i+1 ==16) printf ("\n             ");
  }
  printf ("\n");

  printf ("plaintext' = ");
  for (i=0; i< SPEED_DATA_LEN_BYTE; i++) {
    printf ("%02X ", pt2[SPEED_DATA_LEN_BYTE - 1 -i]);
    if (i+1 ==16) printf ("\n             ");
  }
  printf ("\n");
  printf ("----------------------\n");

  return (0);

}

