
/*  $Id: howfast.c,v 1.3 2003/01/21 08:50:21 lteo Exp $ */

/*
 *  howfast.c:  tests speed of SPEED.
 *
 *  Copyright (c) 2003 Calyptix Security Corporation
 *  All rights reserved.
 *
 *  This code is derived from software contributed to Calyptix Security
 *  Corporation by Yuliang Zheng.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions
 *  are met:
 *  1. Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above
 *     copyright notice, this list of conditions and the following
 *     disclaimer in the documentation and/or other materials provided
 *     with the distribution.
 *  3. Neither the name of Calyptix Security Corporation nor the
 *     names of its contributors may be used to endorse or promote
 *     products derived from this software without specific prior
 *     written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
 * COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
 * ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *
 * -------------------------------------------------------------------
 */

static char rcsid[] = "$Id: howfast.c,v 1.3 2003/01/21 08:50:21 lteo Exp $";

#include <stdio.h>
#include "speedc.h"

#ifdef HAVE_TIME_H
#include <time.h>
#endif /* HAVE_TIME_H */

#include <string.h>

#define NO_OF_DATA 100000L

int main (int  argc, char *argv[]) 
{
  int  i;
  long int	total_bits;
  clock_t       clks;
  double        cpu_time;

  speed_key     key; 
  /* speed_data    pt, ct;  */
  speed_idata   ipt; 
  speed_idata   ict; 
  speed_ikey    rndkey; 

  for (i=0; i<SPEED_KEY_LEN_BYTE; i++) {
    key[i] = 'a' + i;
  }

  for (i=0; i<8; i++) {
    ipt[i] = '0'+i;
  }

  /* reset the clock */
  clock();

  speed_key_schedule(key, rndkey);


  for (i=0; i<NO_OF_DATA; i++) {
    speed_encrypt_rk (ipt, ict, rndkey);
    /* 
    speed_encrypt (pt, ct, key);
    */
  }

  /* get the number clocks */
  clks = clock();
  /* get cpu time */
  cpu_time = (double)clks / (double)CLOCKS_PER_SEC;

  total_bits = NO_OF_DATA * SPEED_DATA_LEN;

  if (cpu_time > 0.0) {
    printf ("Length of data  = %3d bits\n", SPEED_DATA_LEN);
    printf ("Length of key   = %3d bits\n", SPEED_KEY_LEN);
    printf ("No. of rounds   = %3d \n",     SPEED_NO_OF_RND);
    printf ("clock ticks     = %d\n", clks);
    printf ("clock ticks/sec = %ld\n", CLOCKS_PER_SEC);
    printf ("CPU Time        = %4.2f seconds\n", cpu_time);
    printf ("No. of bits     = %ld\n", total_bits);
    printf ("Throughput      = %4.2f megabit/second\n",
    (double)total_bits/(1.0E6 * cpu_time));
    printf ("                = %4.2f bit/clock\n",
    (double)total_bits/(double)clks);
    printf ("--------------------------------------------------\n");
  } else {
    printf ("not enough blocks !\n");
  }

  return 0;
}


